@@ -172,7 +172,10 @@ def get_http_handlers(
                 user["name"] = decoded_access_token["name"]
             user_json = json.dumps(user).encode("ascii")
             user_b64 = b64encode(user_json).decode("utf-8")
-            metadata = {"x-delphai-user": user_b64}
+            metadata = {
+                "authorization": authorization_header,
+                "x-delphai-user": user_b64,
+            }
 
         try:
             raw_output = await process_grpc_request(
